@@ -6,8 +6,10 @@ config <- local({
     message("Loading config from ", filepath)
     newconf <- as.list(fromJSON(filepath));
     for(i in seq_along(newconf)){
-      name <- names(newconf[i]);
-      conflist[[name]] <<- newconf[[i]];
+      val <- newconf[[i]]
+      name <- names(newconf[i])
+      # Turn JSON 'null' value into NA
+      conflist[[name]] <<- ifelse(length(val), val, NA)
     }
   }
 
